@@ -5,7 +5,6 @@ Common type definitions for data encoding and decoding interfaces.
 # built-in
 from enum import Enum
 from io import StringIO
-from logging import Logger
 from pathlib import Path
 from typing import Callable as _Callable
 from typing import Dict as _Dict
@@ -22,8 +21,9 @@ from ruamel.yaml import YAML
 
 # internal
 from vcorelib.dict import merge
+from vcorelib.logging import LoggerType
 from vcorelib.paths import Pathlike as _Pathlike
-from vcorelib.paths import get_file_ext
+from vcorelib.paths import get_file_ext, normalize
 
 DEFAULT_ARCHIVE_EXT = "tar.gz"
 DEFAULT_DATA_EXT = "json"
@@ -50,6 +50,7 @@ class FileExtension(Enum):
     ZIP: _List[str] = ["zip"]
     TAR: _List[str] = [
         DEFAULT_ARCHIVE_EXT,
+        "tgz",
         "tar",
         "tar.bz2",
         "tar.lzma",
@@ -71,12 +72,14 @@ class FileExtension(Enum):
         return self in {FileExtension.ZIP, FileExtension.TAR}
 
     @staticmethod
-    def has_archive(path: Path) -> _Optional[Path]:
+    def has_archive(path: _Pathlike) -> _Optional[Path]:
         """Determine if a path has an associated archive file."""
 
+        path = normalize(path)
+
         for ext in [FileExtension.ZIP, FileExtension.TAR]:
             for ext_str in ext.value:  # pylint: disable=not-an-iterable
-                check_path = Path(f"{path}.{ext_str}")
+                check_path = path.with_suffix(f".{ext_str}")
                 if check_path.is_file():
                     return check_path
 
@@ -113,20 +116,21 @@ class FileExtension(Enum):
         return path.with_suffix("." + str(self))
 
     def candidates(
-        self, path: Path, exists_only: bool = False
+        self, path: _Pathlike, exists_only: bool = False
     ) -> _Iterator[Path]:
         """
         For a given path, iterate over candidate paths that have the suffixes
         for this kind of file extension.
         """
+        orig = normalize(path)
         for ext in self.value:
-            path = path.with_suffix(f".{ext}")
+            path = orig.with_suffix(f".{ext}")
             if not exists_only or path.exists():
                 yield path
 
     @staticmethod
     def archive_candidates(
-        path: Path, exists_only: bool = False
+        path: _Pathlike, exists_only: bool = False
     ) -> _Iterator[Path]:
         """
         Iterate over all file extensions that could point to an archive file.
@@ -138,7 +142,7 @@ class FileExtension(Enum):
 
     @staticmethod
     def data_candidates(
-        path: Path, exists_only: bool = False
+        path: _Pathlike, exists_only: bool = False
     ) -> _Iterator[Path]:
         """
         Iterate over all file extensions that could point to a data file.
@@ -168,7 +172,7 @@ class LoadResult(NamedTuple):
         """Raise a canonical exception if this result is a failure."""
         assert self.success, f"Couldn't load '{path}'!"
 
-    def merge(self, other: "LoadResult") -> "LoadResult":
+    def merge(self, other: "LoadResult", **kwargs) -> "LoadResult":
         """Merge two load results."""
 
         # Add the time fields up if they're both positive.
@@ -177,7 +181,7 @@ class LoadResult(NamedTuple):
             time_ns += other.time_ns
 
         return LoadResult(
-            merge(self.data, other.data),
+            merge(self.data, other.data, **kwargs),
             self.success and other.success,
             time_ns,
         )
@@ -186,8 +190,8 @@ class LoadResult(NamedTuple):
 EncodeResult = _Tuple[bool, int]
 DataStream = _Union[TextIO, StringIO]
 StreamProcessor = _Callable[[DataStream], DataStream]
-DataDecoder = _Callable[[DataStream, Logger], LoadResult]
-DataEncoder = _Callable[[JsonObject, DataStream, Logger], int]
+DataDecoder = _Callable[[DataStream, LoggerType], LoadResult]
+DataEncoder = _Callable[[JsonObject, DataStream, LoggerType], int]
 
 # Only create the interface one so it's not re-created on every read and write
 # attempt.
