@@ -17,10 +17,10 @@ from typing import Tuple as _Tuple
 from typing import Union as _Union
 
 # internal
-from vcorelib.math import KIBI_UNITS as _KIBI_UNITS
-from vcorelib.math import SI_UNITS as _SI_UNITS
-from vcorelib.math import UnitSystem as _UnitSystem
-from vcorelib.math import unit_traverse as _unit_traverse
+from vcorelib.math.unit import KIBI_UNITS as _KIBI_UNITS
+from vcorelib.math.unit import SI_UNITS as _SI_UNITS
+from vcorelib.math.unit import UnitSystem as _UnitSystem
+from vcorelib.math.unit import unit_traverse as _unit_traverse
 
 
 def default_time_ns() -> int:
@@ -88,6 +88,14 @@ def nano_str(
         return stream.getvalue()
 
 
+def rate_str(period_s: float) -> str:
+    """Get a string representing a rate in Hz."""
+
+    period_str = nano_str(int(period_s * 1e9))
+    freq_str = nano_str(int((1.0 / period_s) * 1e9), prefix_space=True)
+    return f"{freq_str}Hz ({period_str}s)"
+
+
 def byte_count_str(byte_count: int) -> str:
     """Get a string representing a number of bytes."""
     return nano_str(byte_count, False, 99, _KIBI_UNITS, True) + "B"
