@@ -3,10 +3,7 @@ Common path manipulation utilities.
 """
 
 # built-in
-from contextlib import suppress as _suppress
-from hashlib import md5 as _md5
 from logging import Logger as _Logger
-from os import stat_result as _stat_result
 from pathlib import Path as _Path
 from typing import Iterable as _Iterable
 from typing import List as _List
@@ -14,39 +11,50 @@ from typing import Optional as _Optional
 from typing import Union as _Union
 
 # third-party
-from pkg_resources import resource_filename as _resource_filename
+import importlib_resources as _importlib_resources
 
 # internal
-from vcorelib import DEFAULT_ENCODING as _DEFAULT_ENCODING
+from vcorelib.paths.base import (
+    Pathlike,
+    get_file_ext,
+    get_file_name,
+    normalize,
+    rel,
+    set_exec_flags,
+    stats,
+)
+from vcorelib.paths.hashing import (
+    DEFAULT_HASH,
+    bytes_hash_hex,
+    bytes_md5_hex,
+    create_hex_digest,
+    file_hash_hex,
+    file_md5_hex,
+    str_hash_hex,
+    str_md5_hex,
+)
 
-Pathlike = _Union[_Path, str, None]
-
-
-def normalize(
-    path: Pathlike, *parts: _Union[str, _Path], require: bool = False
-) -> _Path:
-    """Normalize an input that could be a path into a path."""
-    path = (
-        _Path("." if path is None else path)
-        if not isinstance(path, _Path)
-        else path
-    )
-    path = path.joinpath(*parts)
-
-    if require:
-        assert path.exists(), f"Path '{path}' doesn't exist!"
-
-    return path
-
-
-def stats(path: Pathlike) -> _Optional[_stat_result]:
-    """Get stats for a file on disk if it exists."""
-
-    result = None
-    path = normalize(path)
-    if path.exists():
-        result = path.stat()
-    return result
+__all__ = [
+    "Pathlike",
+    "normalize",
+    "stats",
+    "modified_ns",
+    "modified_after",
+    "get_file_name",
+    "get_file_ext",
+    "DEFAULT_HASH",
+    "bytes_hash_hex",
+    "str_hash_hex",
+    "file_hash_hex",
+    "bytes_md5_hex",
+    "str_md5_hex",
+    "file_md5_hex",
+    "set_exec_flags",
+    "rel",
+    "find_file",
+    "resource",
+    "create_hex_digest",
+]
 
 
 def modified_ns(path: Pathlike) -> _Optional[int]:
@@ -81,38 +89,6 @@ def modified_after(path: Pathlike, candidates: _Iterable[Pathlike]) -> bool:
     return False
 
 
-def get_file_name(path: Pathlike, maxsplit: int = -1) -> str:
-    """
-    From a path to a file, get the name of the file. Use 'maxsplit' to control
-    how many suffixes are considered part of the name or the extension.
-    """
-    split = normalize(path).name.split(".", maxsplit=maxsplit)
-    if len(split) > 1:
-        pieces = split[:-1]
-    else:
-        pieces = [split[0]]
-    return ".".join(pieces)
-
-
-def get_file_ext(path: Pathlike, maxsplit: int = -1) -> str:
-    """
-    From a path to a file, get the file's extension. Use 'maxsplit' to control
-    how many suffixes are considered part of the name or the extension.
-    """
-    return normalize(path).name.split(".", maxsplit=maxsplit)[-1]
-
-
-def str_md5_hex(data: str, encoding: str = _DEFAULT_ENCODING) -> str:
-    """Get an md5 hex string from string data."""
-    return _md5(bytes(data, encoding)).hexdigest()
-
-
-def file_md5_hex(path: Pathlike) -> str:
-    """Get an md5 hex string for a file by path."""
-    with normalize(path).open("rb") as stream:
-        return _md5(stream.read()).hexdigest()
-
-
 def _construct_search_path(
     search_paths: _Iterable[Pathlike] = None,
     include_cwd: bool = False,
@@ -128,7 +104,9 @@ def _construct_search_path(
     # Add a package resource to the search path if a package name was provided.
     if package is not None:
         try:
-            to_check.append(_resource_filename(package, package_subdir))
+            to_check.append(
+                _importlib_resources.files(package).joinpath(package_subdir)
+            )
         except ModuleNotFoundError:
             if logger is not None:
                 logger.warning(
@@ -152,18 +130,6 @@ def _construct_search_path(
     return to_check
 
 
-def rel(path: Pathlike, base: Pathlike = None) -> _Path:
-    """
-    Attempt to make 'path' relative to base (which is the current-working
-    directory, if not provided).
-    """
-
-    path = normalize(path)
-    with _suppress(ValueError):
-        path = path.relative_to(normalize(base).resolve())
-    return path
-
-
 def find_file(
     path: Pathlike,
     *parts: _Union[str, _Path],
