@@ -5,7 +5,9 @@ A task definition for wrapping subprocess's 'run' method.
 # built-in
 from asyncio.subprocess import PIPE as _PIPE
 from asyncio.subprocess import Process as _Process
+from pathlib import Path as _Path
 from sys import executable as _executable
+from typing import List as _List
 
 # internal
 from vcorelib.asyncio.cli import (
@@ -36,7 +38,7 @@ class SubprocessLogMixin(Task):
     async def subprocess_exec(
         self,
         program: str,
-        *caller_args,
+        *caller_args: str,
         args: str = "",
         separator: str = "::",
         stdout: int = None,
@@ -59,37 +61,44 @@ class SubprocessLogMixin(Task):
     async def exec(
         self,
         program: str,
-        *caller_args,
+        *caller_args: str,
         args: str = "",
         separator: str = "::",
         stdout: int = None,
         stderr: int = None,
+        **kwargs,
     ) -> bool:
         """Execute a command and return whether or not it succeeded."""
 
-        proc = await handle_process_cancel(
-            await self.subprocess_exec(
-                program,
-                *caller_args,
-                args=args,
-                separator=separator,
-                stdout=stdout,
-                stderr=stderr,
-            ),
-            self.name,
-            self.log,
-        )
-        return proc.returncode == 0
+        try:
+            proc, _, __ = await handle_process_cancel(
+                await self.subprocess_exec(
+                    program,
+                    *caller_args,
+                    args=args,
+                    separator=separator,
+                    stdout=stdout,
+                    stderr=stderr,
+                    **kwargs,
+                ),
+                self.name,
+                self.log,
+            )
+            return proc.returncode == 0
+        except FileNotFoundError as exc:
+            self.log.exception("Couldn't run command:", exc_info=exc)
+            return False
 
     async def subprocess_shell(
         self,
         cmd: str,
-        *caller_args,
+        *caller_args: str,
         args: str = "",
         joiner: str = " ",
         separator: str = "::",
         stdout: int = None,
         stderr: int = None,
+        **kwargs,
     ) -> _Process:
         """
         Create a process using subprocess shell and log what the command is.
@@ -103,21 +112,23 @@ class SubprocessLogMixin(Task):
             ),
             stdout=stdout,
             stderr=stderr,
+            **kwargs,
         )
 
     async def shell(
         self,
         cmd: str,
-        *caller_args,
+        *caller_args: str,
         args: str = "",
         joiner: str = " ",
         separator: str = "::",
         stdout: int = None,
         stderr: int = None,
+        **kwargs,
     ) -> bool:
         """Execute a shell command and return whether or not it succeeded."""
 
-        proc = await handle_process_cancel(
+        proc, _, __ = await handle_process_cancel(
             await self.subprocess_shell(
                 cmd,
                 *caller_args,
@@ -126,12 +137,28 @@ class SubprocessLogMixin(Task):
                 separator=separator,
                 stdout=stdout,
                 stderr=stderr,
+                **kwargs,
             ),
             self.name,
             self.log,
         )
         return proc.returncode == 0
 
+    async def shell_cmd_in_dir(
+        self,
+        path: _Path,
+        cmd: _List[str],
+        joiner: str = " ",
+        cd: str = "cd",
+        **kwargs,
+    ) -> bool:
+        """Run a shell command in a specific directory."""
+
+        path.mkdir(exist_ok=True)
+        return await self.shell(
+            f'( {cd} "{path}"; {joiner.join(cmd)} )', **kwargs
+        )
+
 
 class SubprocessExec(SubprocessLogMixin):
     """A task wrapping a subprocess."""
@@ -151,7 +178,7 @@ class SubprocessExec(SubprocessLogMixin):
         Create a subprocess, wait for it to exit and add results to the outbox.
         """
 
-        proc = await handle_process_cancel(
+        proc, stdout, stderr = await handle_process_cancel(
             await self.subprocess_exec(
                 program,
                 *caller_args,
@@ -163,8 +190,8 @@ class SubprocessExec(SubprocessLogMixin):
             self.name,
             self.log,
         )
-        outbox["stdout"] = proc.stdout
-        outbox["stderr"] = proc.stderr
+        outbox["stdout"] = stdout
+        outbox["stderr"] = stderr
         outbox["code"] = proc.returncode
 
         return True if not require_success else proc.returncode == 0
@@ -188,13 +215,15 @@ class SubprocessExecStreamed(SubprocessLogMixin):
         Create a subprocess, wait for it to exit and add results to the outbox.
         """
 
-        proc = await handle_process_cancel(
+        proc, stdout, stderr = await handle_process_cancel(
             await self.subprocess_exec(
                 program, *caller_args, args=args, separator=separator
             ),
             self.name,
             self.log,
         )
+        outbox["stdout"] = stdout
+        outbox["stderr"] = stderr
         outbox["code"] = proc.returncode
 
         return True if not require_success else proc.returncode == 0
@@ -219,7 +248,7 @@ class SubprocessShell(SubprocessLogMixin):
         Run a shell command, wait for it to exit and add results to the outbox.
         """
 
-        proc = await handle_process_cancel(
+        proc, stdout, stderr = await handle_process_cancel(
             await self.subprocess_shell(
                 cmd,
                 *caller_args,
@@ -232,8 +261,8 @@ class SubprocessShell(SubprocessLogMixin):
             self.name,
             self.log,
         )
-        outbox["stdout"] = proc.stdout
-        outbox["stderr"] = proc.stderr
+        outbox["stdout"] = stdout
+        outbox["stderr"] = stderr
         outbox["code"] = proc.returncode
 
         return True if not require_success else proc.returncode == 0
@@ -258,7 +287,7 @@ class SubprocessShellStreamed(SubprocessLogMixin):
         Run a shell command, wait for it to exit and add results to the outbox.
         """
 
-        proc = await handle_process_cancel(
+        proc, stdout, stderr = await handle_process_cancel(
             await self.subprocess_shell(
                 cmd,
                 *caller_args,
@@ -269,6 +298,8 @@ class SubprocessShellStreamed(SubprocessLogMixin):
             self.name,
             self.log,
         )
+        outbox["stdout"] = stdout
+        outbox["stderr"] = stderr
         outbox["code"] = proc.returncode
 
         return True if not require_success else proc.returncode == 0
